@@ -594,9 +594,8 @@ gboolean fake_key_press(guint keyval, guint state, gchar **str, gboolean *ret)
     ResetPYStatus();
     show_candwords();
     *ret = TRUE;
-  }else if(iPYInsertPoint && state == 0 && (keyval == GDK_Shift_L ||
-                              keyval == GDK_Control_L ||
-                              keyval == GDK_ISO_Level3_Shift)){
+  }else if(iPYInsertPoint && ((state == 0 && (keyval == GDK_Control_L || keyval == GDK_Shift_L)) ||
+                             (state == 128 && (keyval != GDK_Up || keyval != GDK_Down)))){
       ResetPYStatus();
       show_candwords();
       *ret = FALSE;
@@ -667,5 +666,5 @@ hildon_im_keyboard_decorator_key_event(HildonIMPlugin *plugin,
     return;
   HildonIMKeyboardDecoratorPrivate *priv = HILDON_IM_KEYBOARD_DECORATOR_GET_PRIVATE (plugin);
   client = priv->ui;
-//  g_debug("state:%d keyval:%d code:%d",state,keyval,hardware_keycode);
+  g_debug("state:%d keyval:%d code:%d",state,keyval,hardware_keycode);
 }
