@@ -279,9 +279,11 @@ static Bool LoadPYOtherDict(void)
     bPYOtherDictLoaded = True;
 
     fp = fopen(PY_PHRASE_FILE, "r");
-    if (!fp)
+    if (!fp){
         fprintf(stderr, "Can not find System Database of Pinyin!");
-    else {
+        bPYOtherDictLoaded = False;
+        return False;
+    }else {
         LoadPYPhraseDict(fp, True);
         fclose(fp);
     }
@@ -362,10 +364,8 @@ static INPUT_RETURN_VALUE DoPYInput(unsigned int iKey)
     char *strGet = NULL;
     char strTemp[MAX_USER_INPUT + 1];
 
-    if (!bPYBaseDictLoaded)
-        LoadPYBaseDict();
-    if (!bPYOtherDictLoaded)
-        LoadPYOtherDict();
+    if (!bPYBaseDictLoaded || !bPYOtherDictLoaded)
+        return IRV_DO_NOTHING;
 
     val = IRV_TO_PROCESS;
     if (!bIsPYAddFreq && !bIsPYDelFreq && !bIsPYDelUserPhr) {
