@@ -26,7 +26,7 @@
 
 #define PY_BASE_FILE	"/opt/usr/share/fcitm_kbd/pybase.mb"
 #define PY_PHRASE_FILE	"/opt/usr/share/fcitm_kbd/pyphrase.mb"
-#define PY_INDEX_FILE	"/home/user/.config/fcitx/pyindex_kbd.dat"
+#define PY_INDEX_FILE	"/home/user/.config/fcitx/pyindex.dat"
 
 #define MAX_WORDS_USER_INPUT	32
 #define MAX_PY_PHRASE_LENGTH	10
